@@ -6,10 +6,11 @@ import config
 import dataset
 import lib.transform
 
-from config import set_option, get_option, Config
+from config import set_option, get_option
 from core import *
 from dataset import Dataset
-from lib.transform import interp1d, interp2d, apply_recursive
+#from lib.transform import interp1d, interp2d, apply_recursive
+from lib import *
 
 try:
     from io.nc import read as read_nc, summary as summary_nc
