@@ -64,11 +64,13 @@ class Axis(object):
     modulo: [None] if not None, consider axis values as being defined +/- n*modulo, where n is an integer
 	    this modify `loc` behaviour only, but does not impose any constraint on actual axis values
 
+    tol: [None], if not None, attempt a nearest neighbour search with specified tolerance
+
     + metadata
     """
-    _metadata = MetadataDesc(exclude = ["values", "name", "weights", "modulo"]) # variables which are NOT metadata
+    _metadata = MetadataDesc(exclude = ["values", "name", "weights", "modulo", "tol"]) # variables which are NOT metadata
 
-    def __init__(self, values, name="", weights=None, modulo=None, dtype=None, _monotonic=None, **kwargs):
+    def __init__(self, values, name="", weights=None, modulo=None, dtype=None, _monotonic=None, tol=None, **kwargs):
 	""" 
 	"""
 	if not name:
@@ -101,6 +103,7 @@ class Axis(object):
 	self.name = name 
 	self.weights = weights 
 	self.modulo = modulo
+	self.tol = None # tolerance, when searching an axis
 	self._monotonic = _monotonic
 
 	self._metadata = kwargs
@@ -123,7 +126,7 @@ class Axis(object):
 	else:
 	    weights = self.weights
 
-	return Axis(values, self.name, weights=weights, **self._metadata)
+	return Axis(values, self.name, weights=weights, tol=self.tol, **self._metadata)
 
     def union(self, other):
 	""" join two Axis objects
@@ -217,7 +220,7 @@ class Axis(object):
 	"""
 	assert self.values.ndim == 1, "!!! 2-dimensional axis !!!"
 	if self.is_numeric():
-	    return NumLocator(self.values, modulo=self.modulo)
+	    return NumLocator(self.values, modulo=self.modulo, tol=self.tol)
 	else:
 	    return ObjLocator(self.values)
 
@@ -338,6 +341,9 @@ class GroupedAxis(Axis):
 
     def _get_values(self):
 	# Each element of the new axis is a tuple, which makes a 2-D numpy array
+	if len(self.axes) == 1:
+	    return self.axes[0].values
+
 	aval = _flatten(*[ax.values for ax in self.axes])
 	val = np.empty(aval.shape[0], dtype=object)
 	val[:] = zip(*aval.T.tolist()) # pass a list of tuples
@@ -413,7 +419,9 @@ class GroupedAxis(Axis):
 def _flatten(*list_of_arrays):
     """ flatten a list of arrays ax1, ax2, ... to  a list of tuples [(ax1[0], ax2[0], ax3[0]..), (ax1[0], ax2[0], ax3[1]..), ...]
     """
-    assert len(list_of_arrays) > 1, "only one axis!"
+    assert len(list_of_arrays) > 0, "empty axis"
+    if len(list_of_arrays) == 1:
+	return list_of_arrays[0]
 
     kwargs = dict(indexing="ij")
     grd = np.meshgrid(*list_of_arrays, **kwargs)
@@ -538,19 +546,23 @@ class Axes(list):
 
 	return axes
 
-    def __getitem__(self, item):
+    def __getitem__(self, k):
 	""" get an axis by integer or name
 	"""
-	if type(item) in [str, unicode, tuple, np.string_]:
-	    item = self.get_idx(item)
+	k = self.get_idx(k)
 
-	# confusing
-	#if np.iterable(item):
-	#    return Axes([self[i] for i in item])
-
-	return list.__getitem__(self, item)
+	return list.__getitem__(self, k)
 	#return super(Axes,self)[item]
 
+    def __setitem__(self, k, item):
+	""" get an axis by integer or name
+	"""
+	k = self.get_idx(k)
+	if not isinstance(item, Axis):
+	    raise TypeError("can only set axis type, got: {}".format(item))
+
+	return list.__setitem__(self, k, item)
+
     def __repr__(self):
 	""" string representation
 	"""
@@ -575,9 +587,11 @@ class Axes(list):
 	""" always return axis integer location
 	"""
 	# if axis is already an integer, just return it
-	if type(axis) is int:
+	if type(axis) in (int, np.int_, np.dtype(int)):
 	    return axis
 
+	assert type(axis) in [str, unicode, tuple, np.string_], "unexpected axis index: {}, {}".format(type(axis), axis)
+
 	dims = [ax.name for ax in self]
 
 	return dims.index(axis)
@@ -927,7 +941,7 @@ class NumLocator(LocatorAxis):
     def __init__(self, *args, **kwargs):
 
 	# extract parameters specific to NumLocator
-	opt = {'tol':1e-8, 'modulo':None}
+	opt = {'tol':None, 'modulo':None}
 	for k in kwargs.copy():
 	    if k in opt:
 		opt[k] = kwargs.pop(k)
@@ -958,11 +972,19 @@ class NumLocator(LocatorAxis):
 	    if self.modulo and (val < mi or val > ma):
 		val = _adjust_modulo(val, self.modulo, mi)
 
-	# locate value in axis
-	loc = np.argmin(np.abs(val-values))
+	if self.tol is not None:
 
-	if np.abs(values[loc]-val) > self.tol:
-	    raise IndexError("%f not found within tol %f (closest match %i:%f)" % (val, self.tol, loc, values[loc]))
+	    # locate value in axis
+	    loc = np.argmin(np.abs(val-values))
+
+	    if np.abs(values[loc]-val) > self.tol:
+		raise IndexError("%f not found within tol %f (closest match %i:%f)" % (val, self.tol, loc, values[loc]))
+
+	else:
+	    try:
+		loc = values.tolist().index(val)
+	    except ValueError, msg:
+		raise IndexError("{}. Try setting axis `tol` parameter for nearest neighbor search.".format(msg))
 
 	return loc
 
@@ -1073,6 +1095,11 @@ class LocatorAxes(object):
 	self.axes = axes
 	self.opt = opt
 
+	# fix: ignore "tol" parameter is None, so that axis default is used
+	if 'tol' in self.opt.keys() and self.opt['tol'] is None:
+	    del self.opt['tol']
+
+
     def set(self, **kwargs):
 	""" convenience function for chained call: update methods and return itself 
 	"""
@@ -1086,6 +1113,7 @@ class LocatorAxes(object):
 
 	numpy_indices = ()
 	for i, ix in enumerate(indices):
+
 	    loc = self.axes[i].loc(ix, **self.opt)
 	#    assert np.isscalar(loc) \
 	#	    or type(loc) is slice \
@@ -1096,12 +1124,24 @@ class LocatorAxes(object):
 	return numpy_indices
 
     def __call__(self, indices, axis=0, **opt):
-	"""
-	"""
-	# convert to nd tuple
-	if type(indices) is tuple or isinstance(indices, dict):
-	    assert axis in (None, 0), "cannot have axis > 0 for tuple (multi-dimensional) indexing"
+	""" Convert to N-D tuple
 
+	>>> a = da.array(np.arange(2*3*4).reshape(2,3,4))
+	>>> b = a.group('x1','x2')
+	>>> c = b.take((0,1), axis=1)
+	>>> np.all(a.take({'x1':0,'x2':1}) == c)
+	True
+	"""
+	if isinstance(indices, dict):
+	    assert axis in (None, 0), "cannot have axis > 0 for dict (multi-dimensional) indexing"
+
+	# If already a tuple, shift according to axis (object-type axis)
+	if type(indices) is tuple and axis not in (0, None):
+	    axis = self.axes.get_idx(axis) # make it integer location
+	    indices = tuple([slice(None)]*axis + [indices])
+	    #assert axis in (None, 0), "cannot have axis > 0 for tuple (multi-dimensional) indexing"
+
+	# Convert to a N-D index
 	if type(indices) is not tuple:
 	    
 	    # format (indices=..., axis=...)
