@@ -5,7 +5,7 @@ import copy
 import warnings
 from collections import OrderedDict as odict
 
-from dimarray.config import Config
+from dimarray.config import get_option
 
 from metadata import MetadataDesc
 from axes import Axis, Axes, GroupedAxis
@@ -167,13 +167,17 @@ class DimArray(object):
     # NOW MAIN BODY OF THE CLASS
     #
 
-    def __init__(self, values=None, axes=None, dims=None, labels=None, copy=False, dtype=None, _indexing="values", _indexing_broadcast=True, **kwargs):
+    def __init__(self, values=None, axes=None, dims=None, labels=None, copy=False, dtype=None, _indexing=None, _indexing_broadcast=None, **kwargs):
 	""" Initialization. See help on DimArray.
 	"""
 	# check if attached to values (e.g. DimArray object)
 	if hasattr(values, "axes") and axes is None:
 	    axes = values.axes
 
+	# default options
+	if _indexing is None: _indexing = get_option('indexing')
+	if _indexing_broadcast is None: _indexing_broadcast = get_option('indexing_broadcast')
+
 	#
 	# array values
 	#
@@ -664,6 +668,7 @@ mismatch between values and axes""".format(inferred, self.values.shape)
     #
     reindex_axis = _indexing.reindex_axis
     reindex_like = _indexing.reindex_like
+    sort_axis = _indexing.sort_axis
 
     # Drop missing values
     dropna = missingvalues.dropna
@@ -741,11 +746,11 @@ mismatch between values and axes""".format(inferred, self.values.shape)
 	>>> np.all(s == 5*a)
 	True
 	"""
-	result = _operation.operation(func, self, other, broadcast=Config.op_broadcast, reindex=Config.op_reindex, constructor=self._constructor)
+	result = _operation.operation(func, self, other, broadcast=get_option('op_broadcast'), reindex=get_option('op_reindex'), constructor=self._constructor)
 	return result
 
     def _roperation(self, func, other):
-	return _operation.operation(func, other, self, broadcast=Config.op_broadcast, reindex=Config.op_reindex, constructor=self._constructor)
+	return _operation.operation(func, other, self, broadcast=get_option('op_broadcast'), reindex=get_option('op_reindex'), constructor=self._constructor)
 
     def __neg__(self): return self._constructor(-self.values, self.axes)
     def __pos__(self): return self._constructor(+self.values, self.axes)
@@ -850,6 +855,8 @@ mismatch between values and axes""".format(inferred, self.values.shape)
     def __le__(self, other): return self._cmp('__le__', other)
     def __gt__(self, other): return self._cmp('__gt__', other)
     def __ge__(self, other): return self._cmp('__ge__', other)
+    def __and__(self, other): return self._cmp('__and__', other)
+    def __or__(self, other): return self._cmp('__or__', other)
 
     def __nonzero__(self):
 	""" Boolean value of the object
@@ -931,9 +938,37 @@ mismatch between values and axes""".format(inferred, self.values.shape)
 	       [[ nan,   1.],
 		[  2.,   3.]]])
 	"""
+	from dimarray.dataset import Dataset, odict # 
+	#data = _get_list_arrays(data, keys)	
+
+	if not isinstance(data, dict):
+	    assert isinstance(data, list), "DimArray.from_arrays only acceps dict and list, got {}: {}".format(type(data), data)
+	    if keys is None:
+		keys = []
+		for i, v in enumerate(data):
+		    assert isinstance(v, DimArray), "DimArray.from_arrays only acceps dict and list of DimArray objects, got {}: {}".format(type(v), v)
+		    if not hasattr(v, "name") or v.name is None:
+			name = "v%i"%(i)
+
+		    else:
+			name = v.name
+		    keys.append(name)
+	    data = {keys[i]:v for i, v in enumerate(data)}
+	
+	return cls.from_dict(data, keys=keys, axis=axis)
+
+    @classmethod
+    def from_dict(cls, dict_, keys=None, axis=None):
+	""" Initialize a DimArray for a dictionary of DimArrays
+
+	keys, optional: re-order the keys 
+	axis, optional: give a name to the keys axis
+	"""
+	assert isinstance(dict_, dict)
 	from dimarray.dataset import Dataset
-	data = Dataset(data, keys=keys)
-	return data.to_array(axis=axis)
+	if keys is None: keys = dict_.keys()
+	data = Dataset(dict_)
+	return data.to_array(axis=axis, keys=keys, _constructor=cls._constructor)
 
     @classmethod
     def from_pandas(cls, data, dims=None):
@@ -960,7 +995,11 @@ mismatch between values and axes""".format(inferred, self.values.shape)
 	1 / x1 (2): 0 to 1
 	...  
 	"""
-	import pandas as pd
+	try:
+	    import pandas as pd
+	except ImportError:
+	    raise ImportError("pandas module is required to use this method")
+
 	axisnames = []
 	axes = []
 	for i, ax in enumerate(data.axes):
@@ -998,7 +1037,10 @@ mismatch between values and axes""".format(inferred, self.values.shape)
     def to_pandas(self):
 	""" return the equivalent pandas object
 	"""
-	import pandas as pd
+	try:
+	    import pandas as pd
+	except ImportError:
+	    raise ImportError("pandas module is required to use this method")
 	obj = pandas_obj(self.values, *[ax.to_pandas() for ax in self.axes])
 	return obj
 
@@ -1061,9 +1103,12 @@ mismatch between values and axes""".format(inferred, self.values.shape)
     def to_larry(self):
 	""" return the equivalent pandas object
 	"""
-	import la
+	try:
+	    import la
+	except ImportError:
+	    raise ImportError("la (larry) module is required to use this method")
+
 	a = la.larry(self.values, [list(ax.values) for ax in self.axes])
-	print "warning: dimension names have not been passed to larry"
 	return a
 
     #
@@ -1099,7 +1144,7 @@ mismatch between values and axes""".format(inferred, self.values.shape)
 	    line = repr(self.axes)
 	    lines.append(line)
 
-	if self.size < Config.display_max:
+	if self.size < get_option('display_max'):
 	    line = repr(self.values)
 	else:
 	    line = "array(...)"
