@@ -14,38 +14,42 @@ class Dataset(odict):
 
     _metadata = MetadataDesc(exclude=['axes'])
 
-    def __init__(self, data=None, keys=None, axes=None):
+    def __init__(self, *args, **kwargs):
 	""" initialize a dataset from a set of objects of varying dimensions
 
 	data  : dict of DimArrays or list of named DimArrays or Axes object
 	keys  : keys to order data if provided as dict, or to name data if list
 	"""
-	assert data is None or axes is None, "can't provide both data and axes"
-	#assert keys is None or type(keys) in (list, np.ndarray, tuple) and np.isscalar(keys[0]), "pb with keys"
-	assert keys is None or np.any([isinstance(keys, type_) for type_ in (list, np.ndarray, tuple)]) and np.isscalar(keys[0]), "pb with keys"
+	assert not {'axes','keys'}.issubset(kwargs.keys()) # just to check bugs due to back-compat ==> TO BE REMOVED AFTER DEBUGGING
+
+	# check input arguments: same init as odict
+	kwargs = odict(*args, **kwargs)
+
+	# Basic initialization
+	self.axes = Axes()
 
 	# initialize an ordered dictionary
 	super(Dataset, self).__init__()
 
-	# Basic initialization
-	if axes is None:
-	    axes = Axes()
-	else:
-	    axes = Axes._init(axes)
-	self.axes = axes
+	values = kwargs.values()
+	keys = kwargs.keys()
 
-	# If initialized from data
-	if data is not None:
+        # Check everything is a DimArray
+	#for key, value in zip(keys, values):
+	for i, key in enumerate(keys):
+	    value = values[i]
+	    if not isinstance(value, DimArray):
+		if np.isscalar(value):
+		    values[i] = DimArray(value)
+		else:
+		    raise TypeError("A Dataset can only store DimArray instances, got {}: {}".format(key, value))
 
-	    # First, get a list of named DataFrames
-	    data = _get_list_arrays(data, keys)
+	# Align objects
+	values = align_axes(*values)
 
-	    # Align objects
-	    data = align_axes(*data)
-
-	    # Append object (will automatically update self.axes)
-	    for v in data:
-		self[v.name] = v
+	# Append object (will automatically update self.axes)
+	for key, value in zip(keys, values):
+	    self[key] = value
 
     @property
     def dims(self):
@@ -66,7 +70,9 @@ class Dataset(odict):
 	    dims = self[nm].dims
 	    shape = self[nm].shape
 	    #print nm,":", ", ".join(dims)
-	    lines.append("{}: {}".format(nm,repr(dims)))
+	    repr_dims = repr(dims)
+	    if repr_dims == "()": repr_dims = self[nm].values
+	    lines.append("{}: {}".format(nm,repr_dims))
 	return "\n".join(lines)
 
     def __delitem__(self, item):
@@ -90,29 +96,25 @@ class Dataset(odict):
 
 	Tests:
 	-----
-	>>> axes = da.Axes.from_tuples(('time',[1, 2, 3]))
-	>>> ds = Dataset(axes=axes)
+#	>>> axes = da.Axes.from_tuples(('time',[1, 2, 3]))
+	>>> ds = Dataset()
 	>>> ds
 	Dataset of 0 variables
-	dimensions: 'time'
-	0 / time (3): 1 to 3
+	dimensions: 
+	<BLANKLINE>
 	>>> a = DimArray([0, 1, 2], dims=('time',))
-	>>> ds['yo'] = a # doctest: +SKIP
-	ValueError: axes values do not match, align data first.			    
-	Dataset: time(3)=1:3, 
-	Got: time(3)=0:2
-	>>> ds['yo'] = a.reindex_like(ds)
+	>>> ds['yo'] = a 
 	>>> ds['yo']
-	dimarray: 2 non-null elements (1 null)
+	dimarray: 3 non-null elements (0 null)
 	dimensions: 'time'
-	0 / time (3): 1 to 3
-	array([  1.,   2.,  nan])
+	0 / time (3): 0 to 2
+	array([0, 1, 2])
 	"""
 	if not isinstance(val, DimArray):
-	    raise TypeError("can only append DimArray instances")
-
-	if not np.isscalar(key):
-	    raise TypeError("only scalar keys allowed")
+	    if np.isscalar(val):
+		val = DimArray(val)
+	    else:
+		raise TypeError("can only append DimArray instances")
 
 	# Check dimensions
 	for axis in val.axes:
@@ -144,12 +146,10 @@ class Dataset(odict):
 
     read = read_nc
 
-    def to_array(self, axis=None):
+    def to_array(self, axis=None, keys=None, _constructor=None):
 	""" Convert to DimArray
 
 	axis  : axis name, by default "unnamed"
-
-	NOTE: will raise an error if axis name already present in the data
 	"""
 	#if names is not None or dims is not None:
 	#    return self.subset(names=names, dims=dims).to_array()
@@ -166,19 +166,159 @@ class Dataset(odict):
 	    raise ValueError("please provide an axis name which does not \
 		    already exist in Dataset")
 
+	if keys is None:
+	    keys = self.keys()
+
 	# align all variables to the same dimensions
 	data = odict()
-	for k in self:
+
+	for k in keys:
 	    data[k] = self[k].reshape(self.dims).broadcast(self.axes)
 
 	# make it a numpy array
-	data = [data[k].values for k in self]
+	data = [data[k].values for k in keys]
 	data = np.array(data)
 
 	# determine axes
-	axes = [Axis(self.keys(), axis)] + self.axes 
+	axes = [Axis(keys, axis)] + self.axes 
 
-	return DimArray(data, axes)
+	if _constructor is None: _constructor = DimArray
+	return _constructor(data, axes)
+
+
+    def take(self, indices, axis=0, raise_error=True, **kwargs):
+	""" analogous to DimArray's take, but for each DimArray of the Dataset
+
+	parameters:
+	-----------
+	indices: scalar, or array-like, or slice
+	axis: axis name (str)
+	raise_error: raise an error if a variable does not have the desired dimension
+	**kwargs: arguments passed to the axis locator, similar to `take`, such as `indexing` or `keepdims`
+
+	parameters:
+	-----------
+
+
+	Examples:
+	---------
+	>>> a = DimArray([1,2,3], axes=('time', [1950, 1951, 1952]))
+	>>> b = DimArray([11,22,33], axes=('time', [1951, 1952, 1953]))
+	>>> ds = Dataset(a=a, b=b)
+	>>> ds
+	Dataset of 2 variables
+	dimensions: 'time'
+	0 / time (4): 1950 to 1953
+	a: ('time',)
+	b: ('time',)
+	>>> ds.take(1951, axis='time')
+	Dataset of 2 variables
+	dimensions: 
+	<BLANKLINE>
+	a: 2.0
+	b: 11.0
+	>>> ds.take(0, axis='time', indexing='position')
+	Dataset of 2 variables
+	dimensions: 
+	<BLANKLINE>
+	a: 1.0
+	b: nan
+	"""
+	assert isinstance(axis, str), "axis must be a string"
+	ii = self.axes[axis].loc(indices, **kwargs)
+	newdata = self.copy() # copy the dict
+	for k in self.keys():
+	    if axis not in self[k].dims: 
+		if raise_error: 
+		    raise ValueError("{} does not have dimension {} ==> set raise_error=False to keep this variable unchanged".format(k, axis))
+		else:
+		    continue
+	    a = self[k].take(ii, axis=axis, indexing='position')
+	    if not isinstance(a, DimArray):
+		a = DimArray(a)
+	    odict.__setitem__(newdata, k, a)
+
+	# update the axis
+	newaxis = self.axes[axis][ii]
+	if type(axis) is not int: axis = self.dims.index(axis) # axis is int
+
+	# remove if axis collapsed
+	if not isinstance(newaxis, Axis):
+	    del newdata.axes[axis]
+
+	# otherwise update
+	else:
+	    newdata.axes[axis] = newaxis
+
+	return newdata
+
+    def _apply_dimarray_axis(self, funcname, *args, **kwargs):
+	""" Apply a function on every Dataset variable. 
+	
+	If the 'axis=' parameter is passed, only the variables with the required axis are called.
+	"""
+	axis = kwargs.pop('axis',None)
+	if axis is not None: axis = self.axes[axis].name
+	kwargs['axis'] = axis
+
+	d = odict(self)
+	for k in self.keys():
+	    if axis is not None and axis not in self[k].dims: 
+		continue
+	    #d[k] = self[k].apply(func, *args, **kwargs)
+	    d[k] = getattr(self[k], funcname)(*args, **kwargs)
+
+	return Dataset(d)
+
+    def mean(self, axis=0, **kwargs):
+	""" Apply transformantion on every variable of the Dataset
+
+	Examples:
+	---------
+	>>> a = DimArray([1,2,3], axes=('time', [1950, 1951, 1952]))
+	>>> b = DimArray([[11,22,33],[44,55,66]], axes=[('items',['a','b']), ('time', [1950, 1951, 1952])])
+	>>> ds = Dataset(a=a, b=b)
+	>>> ds.mean(axis='time')
+	Dataset of 2 variables
+	dimensions: 'items'
+	0 / items (2): a to b
+	a: 2.0
+	b: ('items',)
+	>>> ds.mean(axis='items')
+	Dataset of 2 variables
+	dimensions: 'time'
+	0 / time (3): 1950 to 1952
+	a: ('time',)
+	b: ('time',)
+	"""
+	return self._apply_dimarray_axis('mean', axis=axis, **kwargs)
+
+    def std(self, axis=0, **kwargs): return self._apply_dimarray_axis('std', axis=axis, **kwargs)
+    def var(self, axis=0, **kwargs): return self._apply_dimarray_axis('var', axis=axis, **kwargs)
+    def median(self, axis=0, **kwargs): return self._apply_dimarray_axis('median', axis=axis, **kwargs)
+
+    def __getattr__(self, att):
+	""" allow access of dimensions
+	"""
+	# check for dimensions
+	if att in self.dims:
+	    ax = self.axes[att]
+	    return ax.values # return numpy array
+
+	else:
+	    raise AttributeError("{} object has no attribute {}".format(self.__class__.__name__, att))
+
+    def to_dict(self):
+	""" export to dict
+	"""
+	return dict(self)
+
+    def to_odict(self):
+	""" export to ordered dict
+	"""
+	return odict(self)
+
+    #def dropna(self, axis=0, **kwargs): return self._apply_dimarray_axis('dropna', axis=axis, **kwargs)
 
 #    def subset(self, names=None, dims=None):
 #	""" return a subset of the dictionary
@@ -255,19 +395,19 @@ def test():
     array([  0.,   1.,   2.,   3.,   4.,  nan,  nan,  nan,  nan,  nan])
     >>> data.to_array(axis='items')
     dimarray: 12250 non-null elements (1750 null)
-    dimensions: 'items', 'time', 'lon', 'lat', 'source'
-    0 / items (4): ts to test
-    1 / time (10): 1950 to 1959
-    2 / lon (50): -180.0 to 180.0
-    3 / lat (7): -90.0 to 90.0
+    dimensions: 'items', 'lon', 'lat', 'time', 'source'
+    0 / items (4): mymap to test
+    1 / lon (50): -180.0 to 180.0
+    2 / lat (7): -90.0 to 90.0
+    3 / time (10): 1950 to 1959
     4 / source (1): greenland to greenland
     array(...)
     """
     import dimarray as da
     axes = da.Axes.from_tuples(('time',[1, 2, 3]))
-    ds = da.Dataset(axes=axes)
+    ds = da.Dataset()
     a = da.DimArray([[0, 1],[2, 3]], dims=('time','items'))
-    ds['yo'] = a.reindex_like(ds)
+    ds['yo'] = a.reindex_like(axes)
 
     np.random.seed(0)
     mymap = da.DimArray.from_kw(np.random.randn(50,7), lon=np.linspace(-180,180,50), lat=np.linspace(-90,90,7))
@@ -276,7 +416,7 @@ def test():
 
     # Define a Dataset made of several variables
     data = da.Dataset({'ts':ts, 'ts2':ts2, 'mymap':mymap})
-    data = da.Dataset([ts, ts2, mymap], keys=['ts','ts2','mymap'])
+    #data = da.Dataset([ts, ts2, mymap], keys=['ts','ts2','mymap'])
 
     assert np.all(data['ts'].time == data['ts2'].time),"Dataset: pb data alignment" 
 
