@@ -2,6 +2,7 @@
 """
 import os
 from collections import OrderedDict as odict
+import warnings
 import netCDF4 as nc
 import numpy as np
 #from geo.data.index import to_slice, _slice3D
@@ -84,7 +85,12 @@ def read_dimensions(f, name=None, ix=slice(None), verbose=False):
     axes = Axes()
     for k in dims:
 
-	values = f.variables[k][ix]
+	try:
+	    values = f.variables[k][ix]
+	except KeyError:
+	    msg = "'{}' dimension not found, define integer range".format(k)
+	    warnings.warn(msg)
+	    values = np.arange(len(f.dimensions[k]))
 
 	# replace unicode by str as a temporary bug fix (any string seems otherwise to be treated as unicode in netCDF4)
 	if values.size > 0 and type(values[0]) is unicode:
@@ -208,7 +214,8 @@ def read_dataset(f, nms=None, *args, **kwargs):
     data = dict()
     for nm in nms:
 	data[nm] = read_variable(f, nm, *args, **kwargs)
-    data = Dataset(data, keys=nms)
+
+    data = Dataset(**data)
 
     # get dataset's metadata
     for k in f.ncattrs():
@@ -225,17 +232,19 @@ def read_dataset(f, nms=None, *args, **kwargs):
 def write_obj(f, obj, *args, **kwargs):
     """  call write_dataset or write_variable
     """
-    import core
-    if isinstance(obj, core.DimArray):
+    if isinstance(obj, DimArray):
 	write_variable(f, obj, *args, **kwargs)
 
-    else:
+    elif isinstance(obj, Dataset):
 	write_dataset(f, obj, *args, **kwargs)
 
-def write_dataset(f, obj, mode='w-'):
+    else:
+	raise TypeError("only DimArray or Dataset types allowed, got {}:{}".format(type(obj), obj))
+
+def write_dataset(f, obj, mode='w-', **kwargs):
     """ write object to file
     """
-    f, close = check_file(f, mode)
+    f, close = check_file(f, mode, **kwargs)
     nms = obj.keys()
     for nm in obj:
 	write_variable(f, obj[nm], nm)
@@ -283,7 +292,7 @@ def createVariable(f, name, axes=None, dtype=float, **kwargs):
 
 #def write_attributes(f, obj):
 
-def write_variable(f, obj, name=None, mode='a+', indices=None, axis=0, verbose=False, **kwargs):
+def write_variable(f, obj, name=None, mode='a+', format='NETCDF4', indices=None, axis=0, verbose=False, **kwargs):
     """ save DimArray instance to file
 
     f	: file name or netCDF file handle
@@ -295,7 +304,7 @@ def write_variable(f, obj, name=None, mode='a+', indices=None, axis=0, verbose=F
     assert name, "invalid variable name !"
 
     # control wether file name or netCDF handle
-    f, close = check_file(f, mode=mode, verbose=verbose)
+    f, close = check_file(f, mode=mode, verbose=verbose, format=format)
 
     # create variable if necessary
     if name not in f.variables:
@@ -359,7 +368,7 @@ def scan_var(f, v, **verb):
     return dims, shape
 
 
-def check_file(f, mode='r', verbose=True):
+def check_file(f, mode='r', verbose=True, format='NETCDF4'):
     """ open a netCDF4 file
 
     mode: changed from original 'r','w','r' & clobber option:
@@ -369,6 +378,9 @@ def check_file(f, mode='r', verbose=True):
     'w-': create new file, but raise Exception if file is present (clobber=False)
     'a' : append, raise Exception if file is not present
     'a+': append if file is present, otherwise create
+
+    format: passed to netCDF4.Dataset, only relevatn when mode = 'w', 'w-', 'a+'
+	'NETCDF4', 'NETCDF4_CLASSIC', 'NETCDF3_CLASSIC', 'NETCDF3_64BIT'
     """
     close = False
 
@@ -393,7 +405,7 @@ def check_file(f, mode='r', verbose=True):
 	    os.remove(fname)
 
 	try:
-	    f = nc.Dataset(fname, mode, clobber=clobber)
+	    f = nc.Dataset(fname, mode, clobber=clobber, format=format)
 
 	except UserWarning, msg:
 	    print msg
